/*
 * pfr.c - read an ASCI file from the network which was written 
 *         as a permuted sequence of encapsulated rot(n) encrypted 
 *         cookienet packets.
 */
#include <stdio.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/file.h>
#include <sys/time.h>
#include <net/pfilt.h>

#include "lib.h"

#define COOKIENET 0x0011	/* cookienet packet type */
#define ANYPORT 0xffff		/* accept cookienet on any port */
#define DEFAULTPORT 1024	/* default cookienet port */
#define MAXPAYLOAD 1024		/* maximum cookienet payload */
#define MAXLINES 1024		/* maximum lines per cookienet message */
#define MAXPORTNUM 0xffff	/* maximum port number */
#define INTERFACE "pf1"		/* ethernet card to read from */

/* function prototypes */
struct packet *readpacket(int fd, int port, int *packetsize);
void printpacket(struct packet *p, int packetsize);
char unrotn(char c, int n); 
void usage();
void err(char *s);

/* globals */
char *progname;

int main(int argc, char **argv) {
  int i;
  int fd;
  int port;
  int packetsize;
  struct packet *p;
  
  progname = argv[0];

  /* must specify a port number */
  if (argc < 2) {
    usage();
    exit(0);
  }

  /* parse the command line */
  port = ANYPORT; /* default is to read from all cookienet ports */
  for (i=1; i<argc; i++) {
    if (argv[i][0] == '-') {
      if (argv[i][1] == 'h') {
	usage();
	exit(0);
      }
    }
    else {
      port = atoi(&argv[i][0]);
    }
  }
  if (port < 0) {
    printf("%s: bad port number\n", argv[0]);
    exit(0);
  }

  /* find an available (nonbusy) input packet filter */
  fd = openinpf();
  fprintf(stderr, "Reading type 0x%04x pkts on port %d from interface %s\n", 
	  COOKIENET, port, INTERFACE);

  /* read and decode cookienet messages sent to a particular port */
  while (1) {
    p = readpacket(fd, port, &packetsize);
    printpacket(p, packetsize);
  }
}

/*
 * err - wrapper for the Unix perror routine
 */
void err(char *s) {
  perror(s);
  exit(0);
}

void usage() {
  printf("Usage: %s [-h] <port>\n", 
	 progname);
  printf("\n");
  printf("Reads rot(n) encrypted cookienet packets addressed to port <port>");
  printf("and prints them to stdout.");
  printf("\n");
  printf("Options:\n");
  printf("  -h    : print this message\n");
  printf("  <port>: read from this cookienet port\n");
  printf("\n");
}

/*
 * readpacket - read an encapsulated cookienet packet 
 * inputs: 
 *    fd   - packetfilter's file descriptor
 *    port - read only packets addressed to this 
 *           cookienet port. If (port==ANYPORT) then
 *           read packets sent to all port).
 * outputs:
 *    return val - pointer to the packet
 *    packetsize - packet size in bytes
 */
struct packet *readpacket(int fd, int port, int *packetsize) {

}

/*
 * printpacket - print an encapsulated cookienet packet whose 
 *               ethernet packet consists of packetsize bytes 
 */
void printpacket(struct packet *p, int packetsize) {

}

/*
 * unrotn - given a rot(n) encoded character, return the
 *          original character
 */
char unrotn(char c, int n) {

}


